@@ -171,6 +171,8 @@ option_strings = {
     'entry_cache_timeout' : _('Entry cache timeout length (seconds)'),
     'lookup_family_order' : _('Restrict or prefer a specific address family when performing DNS lookups'),
     'account_cache_expiration' : _('How long to keep cached entries after last successful login (days)'),
+    'dns_resolver_server_timeout' : _('How long should SSSD talk to single DNS server before trying next server (miliseconds)'),
+    'dns_resolver_op_timeout' : _('How long should keep trying to resolve single DNS query (seconds)'),
     'dns_resolver_timeout' : _('How long to wait for replies from DNS when resolving servers (seconds)'),
     'dns_discovery_domain' : _('The domain part of service discovery DNS query'),
     'override_gid' : _('Override GID value from the identity provider with this value'),
@@ -282,6 +284,7 @@ option_strings = {
     'ldap_backup_uri' : _('ldap_backup_uri, The URI of the LDAP server'),
     'ldap_search_base' : _('The default base DN'),
     'ldap_schema' : _('The Schema Type in use on the LDAP server, rfc2307'),
+    'ldap_pwmodify_mode' : _('Mode used to change user password'),
     'ldap_default_bind_dn' : _('The default bind DN'),
     'ldap_default_authtok_type' : _('The type of the authentication token of the default bind DN'),
     'ldap_default_authtok' : _('The authentication token of the default bind DN'),
